@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import random
 import time
 
@@ -30,10 +28,10 @@ class ServiceTest(BaseAPIIntegrationTest):
                 self.client.remove_service(service['ID'])
             except docker.errors.APIError:
                 pass
-        super(ServiceTest, self).tearDown()
+        super().tearDown()
 
     def get_service_name(self):
-        return 'dockerpytest_{0:x}'.format(random.getrandbits(64))
+        return f'dockerpytest_{random.getrandbits(64):x}'
 
     def get_service_container(self, service_name, attempts=20, interval=0.5,
                               include_stopped=False):
@@ -54,7 +52,7 @@ class ServiceTest(BaseAPIIntegrationTest):
 
     def create_simple_service(self, name=None, labels=None):
         if name:
-            name = 'dockerpytest_{0}'.format(name)
+            name = f'dockerpytest_{name}'
         else:
             name = self.get_service_name()
 
@@ -403,20 +401,20 @@ class ServiceTest(BaseAPIIntegrationTest):
         node_id = self.client.nodes()[0]['ID']
         container_spec = docker.types.ContainerSpec(TEST_IMG, ['true'])
         task_tmpl = docker.types.TaskTemplate(
-            container_spec, placement=['node.id=={}'.format(node_id)]
+            container_spec, placement=[f'node.id=={node_id}']
         )
         name = self.get_service_name()
         svc_id = self.client.create_service(task_tmpl, name=name)
         svc_info = self.client.inspect_service(svc_id)
         assert 'Placement' in svc_info['Spec']['TaskTemplate']
         assert (svc_info['Spec']['TaskTemplate']['Placement'] ==
-                {'Constraints': ['node.id=={}'.format(node_id)]})
+                {'Constraints': [f'node.id=={node_id}']})
 
     def test_create_service_with_placement_object(self):
         node_id = self.client.nodes()[0]['ID']
         container_spec = docker.types.ContainerSpec(TEST_IMG, ['true'])
         placemt = docker.types.Placement(
-            constraints=['node.id=={}'.format(node_id)]
+            constraints=[f'node.id=={node_id}']
         )
         task_tmpl = docker.types.TaskTemplate(
             container_spec, placement=placemt
@@ -508,7 +506,7 @@ class ServiceTest(BaseAPIIntegrationTest):
                 assert port['TargetPort'] == 1990
                 assert port['Protocol'] == 'udp'
             else:
-                self.fail('Invalid port specification: {0}'.format(port))
+                self.fail(f'Invalid port specification: {port}')
 
         assert len(ports) == 3
 
@@ -670,14 +668,14 @@ class ServiceTest(BaseAPIIntegrationTest):
         container = self.get_service_container(name)
         assert container is not None
         exec_id = self.client.exec_create(
-            container, 'cat /run/secrets/{0}'.format(secret_name)
+            container, f'cat /run/secrets/{secret_name}'
         )
         assert self.client.exec_start(exec_id) == secret_data
 
     @requires_api_version('1.25')
     def test_create_service_with_unicode_secret(self):
         secret_name = 'favorite_touhou'
-        secret_data = u'東方花映塚'
+        secret_data = '東方花映塚'
         secret_id = self.client.create_secret(secret_name, secret_data)
         self.tmp_secrets.append(secret_id)
         secret_ref = docker.types.SecretReference(secret_id, secret_name)
@@ -695,7 +693,7 @@ class ServiceTest(BaseAPIIntegrationTest):
         container = self.get_service_container(name)
         assert container is not None
         exec_id = self.client.exec_create(
-            container, 'cat /run/secrets/{0}'.format(secret_name)
+            container, f'cat /run/secrets/{secret_name}'
         )
         container_secret = self.client.exec_start(exec_id)
         container_secret = container_secret.decode('utf-8')
@@ -722,14 +720,14 @@ class ServiceTest(BaseAPIIntegrationTest):
         container = self.get_service_container(name)
         assert container is not None
         exec_id = self.client.exec_create(
-            container, 'cat /{0}'.format(config_name)
+            container, f'cat /{config_name}'
         )
         assert self.client.exec_start(exec_id) == config_data
 
     @requires_api_version('1.30')
     def test_create_service_with_unicode_config(self):
         config_name = 'favorite_touhou'
-        config_data = u'東方花映塚'
+        config_data = '東方花映塚'
         config_id = self.client.create_config(config_name, config_data)
         self.tmp_configs.append(config_id)
         config_ref = docker.types.ConfigReference(config_id, config_name)
@@ -747,7 +745,7 @@ class ServiceTest(BaseAPIIntegrationTest):
         container = self.get_service_container(name)
         assert container is not None
         exec_id = self.client.exec_create(
-            container, 'cat /{0}'.format(config_name)
+            container, f'cat /{config_name}'
         )
         container_config = self.client.exec_start(exec_id)
         container_config = container_config.decode('utf-8')
@@ -1136,7 +1134,7 @@ class ServiceTest(BaseAPIIntegrationTest):
                 assert port['TargetPort'] == 1990
                 assert port['Protocol'] == 'udp'
             else:
-                self.fail('Invalid port specification: {0}'.format(port))
+                self.fail(f'Invalid port specification: {port}')
 
         assert len(ports) == 3
 
@@ -1163,7 +1161,7 @@ class ServiceTest(BaseAPIIntegrationTest):
                 assert port['TargetPort'] == 1990
                 assert port['Protocol'] == 'udp'
             else:
-                self.fail('Invalid port specification: {0}'.format(port))
+                self.fail(f'Invalid port specification: {port}')
 
         assert len(ports) == 3
 
